@@ -24,25 +24,40 @@
 
 This AWS Solutions Construct implements an Amazon CloudFront distribution to an AWS Elemental MediaStore container.
 
-Here is a minimal deployable pattern definition in TypeScript:
+Here is a minimal deployable pattern definition:
+
+Typescript
 
 ```python
+import { Construct } from 'constructs';
+import { Stack, StackProps } from 'aws-cdk-lib';
 import { CloudFrontToMediaStore } from '@aws-solutions-constructs/aws-cloudfront-mediastore';
 
 new CloudFrontToMediaStore(this, 'test-cloudfront-mediastore-default', {});
 ```
 
-## Initializer
+Python
 
-```text
-new CloudFrontToMediaStore(scope: Construct, id: string, props: CloudFrontToMediaStoreProps);
+```python
+from aws_solutions_constructs.aws_cloudfront_mediastore import CloudFrontToMediaStore
+from aws_cdk import Stack
+from constructs import Construct
+
+CloudFrontToMediaStore(self, 'test-cloudfront-mediastore-default')
 ```
 
-*Parameters*
+Java
 
-* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
-* id `string`
-* props [`CloudFrontToMediaStoreProps`](#pattern-construct-props)
+```java
+import software.constructs.Construct;
+
+import software.amazon.awscdk.Stack;
+import software.amazon.awscdk.StackProps;
+import software.amazon.awsconstructs.services.cloudfrontmediastore.*;
+
+new CloudFrontToMediaStore(this, "test-cloudfront-mediastore-default", new CloudFrontToMediaStoreProps.Builder()
+        .build());
+```
 
 ## Pattern Construct Props
 
